# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.injective.exchange.v2 import exchange_pb2 as injective_dot_exchange_dot_v2_dot_exchange__pb2
from pyinjective.proto.injective.exchange.v2 import market_pb2 as injective_dot_exchange_dot_v2_dot_market__pb2
from pyinjective.proto.injective.exchange.v2 import order_pb2 as injective_dot_exchange_dot_v2_dot_order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/exchange/v2/events.proto\x12\x15injective.exchange.v2\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a$injective/exchange/v2/exchange.proto\x1a\"injective/exchange/v2/market.proto\x1a!injective/exchange/v2/order.proto\"\xd2\x01\n\x17\x45ventBatchSpotExecution\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12J\n\rexecutionType\x18\x03 \x01(\x0e\x32$.injective.exchange.v2.ExecutionTypeR\rexecutionType\x12\x37\n\x06trades\x18\x04 \x03(\x0b\x32\x1f.injective.exchange.v2.TradeLogR\x06trades\"\xdd\x02\n\x1d\x45ventBatchDerivativeExecution\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12%\n\x0eis_liquidation\x18\x03 \x01(\x08R\risLiquidation\x12R\n\x12\x63umulative_funding\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11\x63umulativeFunding\x12J\n\rexecutionType\x18\x05 \x01(\x0e\x32$.injective.exchange.v2.ExecutionTypeR\rexecutionType\x12\x41\n\x06trades\x18\x06 \x03(\x0b\x32).injective.exchange.v2.DerivativeTradeLogR\x06trades\"\xc2\x02\n\x1d\x45ventLostFundsFromLiquidation\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\x0cR\x0csubaccountId\x12x\n\'lost_funds_from_available_during_payout\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\"lostFundsFromAvailableDuringPayout\x12\x65\n\x1dlost_funds_from_order_cancels\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x19lostFundsFromOrderCancels\"\x84\x01\n\x1c\x45ventBatchDerivativePosition\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12G\n\tpositions\x18\x02 \x03(\x0b\x32).injective.exchange.v2.SubaccountPositionR\tpositions\"\xbb\x01\n\x1b\x45ventDerivativeMarketPaused\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12.\n\x13total_missing_funds\x18\x03 \x01(\tR\x11totalMissingFunds\x12,\n\x12missing_funds_rate\x18\x04 \x01(\tR\x10missingFundsRate\"P\n\x19\x45ventSettledMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"S\n\x1c\x45ventNotSettledMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"\x8f\x01\n\x1b\x45ventMarketBeyondBankruptcy\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12\x30\n\x14missing_market_funds\x18\x03 \x01(\tR\x12missingMarketFunds\"\x88\x01\n\x18\x45ventAllPositionsHaircut\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12,\n\x12missing_funds_rate\x18\x03 \x01(\tR\x10missingFundsRate\"j\n\x1e\x45ventBinaryOptionsMarketUpdate\x12H\n\x06market\x18\x01 \x01(\x0b\x32*.injective.exchange.v2.BinaryOptionsMarketB\x04\xc8\xde\x1f\x00R\x06market\"\xbf\x01\n\x12\x45ventNewSpotOrders\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x44\n\nbuy_orders\x18\x02 \x03(\x0b\x32%.injective.exchange.v2.SpotLimitOrderR\tbuyOrders\x12\x46\n\x0bsell_orders\x18\x03 \x03(\x0b\x32%.injective.exchange.v2.SpotLimitOrderR\nsellOrders\"\xd1\x01\n\x18\x45ventNewDerivativeOrders\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12J\n\nbuy_orders\x18\x02 \x03(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderR\tbuyOrders\x12L\n\x0bsell_orders\x18\x03 \x03(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderR\nsellOrders\"v\n\x14\x45ventCancelSpotOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x41\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v2.SpotLimitOrderB\x04\xc8\xde\x1f\x00R\x05order\"X\n\x15\x45ventSpotMarketUpdate\x12?\n\x06market\x18\x01 \x01(\x0b\x32!.injective.exchange.v2.SpotMarketB\x04\xc8\xde\x1f\x00R\x06market\"\x98\x02\n\x1a\x45ventPerpetualMarketUpdate\x12\x45\n\x06market\x18\x01 \x01(\x0b\x32\'.injective.exchange.v2.DerivativeMarketB\x04\xc8\xde\x1f\x00R\x06market\x12\x64\n\x15perpetual_market_info\x18\x02 \x01(\x0b\x32*.injective.exchange.v2.PerpetualMarketInfoB\x04\xc8\xde\x1f\x01R\x13perpetualMarketInfo\x12M\n\x07\x66unding\x18\x03 \x01(\x0b\x32-.injective.exchange.v2.PerpetualMarketFundingB\x04\xc8\xde\x1f\x01R\x07\x66unding\"\xda\x01\n\x1e\x45ventExpiryFuturesMarketUpdate\x12\x45\n\x06market\x18\x01 \x01(\x0b\x32\'.injective.exchange.v2.DerivativeMarketB\x04\xc8\xde\x1f\x00R\x06market\x12q\n\x1a\x65xpiry_futures_market_info\x18\x03 \x01(\x0b\x32..injective.exchange.v2.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x01R\x17\x65xpiryFuturesMarketInfo\"\xc7\x02\n!EventPerpetualMarketFundingUpdate\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12M\n\x07\x66unding\x18\x02 \x01(\x0b\x32-.injective.exchange.v2.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00R\x07\x66unding\x12*\n\x11is_hourly_funding\x18\x03 \x01(\x08R\x0fisHourlyFunding\x12\x46\n\x0c\x66unding_rate\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x66undingRate\x12\x42\n\nmark_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\"\x97\x01\n\x16\x45ventSubaccountDeposit\x12\x1f\n\x0bsrc_address\x18\x01 \x01(\tR\nsrcAddress\x12#\n\rsubaccount_id\x18\x02 \x01(\x0cR\x0csubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\x98\x01\n\x17\x45ventSubaccountWithdraw\x12#\n\rsubaccount_id\x18\x01 \x01(\x0cR\x0csubaccountId\x12\x1f\n\x0b\x64st_address\x18\x02 \x01(\tR\ndstAddress\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\xb1\x01\n\x1e\x45ventSubaccountBalanceTransfer\x12*\n\x11src_subaccount_id\x18\x01 \x01(\tR\x0fsrcSubaccountId\x12*\n\x11\x64st_subaccount_id\x18\x02 \x01(\tR\x0f\x64stSubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"h\n\x17\x45ventBatchDepositUpdate\x12M\n\x0f\x64\x65posit_updates\x18\x01 \x03(\x0b\x32$.injective.exchange.v2.DepositUpdateR\x0e\x64\x65positUpdates\"\xc2\x01\n\x1b\x44\x65rivativeMarketOrderCancel\x12U\n\x0cmarket_order\x18\x01 \x01(\x0b\x32,.injective.exchange.v2.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01R\x0bmarketOrder\x12L\n\x0f\x63\x61ncel_quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0e\x63\x61ncelQuantity\"\x9d\x02\n\x1a\x45ventCancelDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12$\n\risLimitCancel\x18\x02 \x01(\x08R\risLimitCancel\x12R\n\x0blimit_order\x18\x03 \x01(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01R\nlimitOrder\x12h\n\x13market_order_cancel\x18\x04 \x01(\x0b\x32\x32.injective.exchange.v2.DerivativeMarketOrderCancelB\x04\xc8\xde\x1f\x01R\x11marketOrderCancel\"b\n\x18\x45ventFeeDiscountSchedule\x12\x46\n\x08schedule\x18\x01 \x01(\x0b\x32*.injective.exchange.v2.FeeDiscountScheduleR\x08schedule\"\xd8\x01\n EventTradingRewardCampaignUpdate\x12U\n\rcampaign_info\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v2.TradingRewardCampaignInfoR\x0c\x63\x61mpaignInfo\x12]\n\x15\x63\x61mpaign_reward_pools\x18\x02 \x03(\x0b\x32).injective.exchange.v2.CampaignRewardPoolR\x13\x63\x61mpaignRewardPools\"p\n\x1e\x45ventTradingRewardDistribution\x12N\n\x0f\x61\x63\x63ount_rewards\x18\x01 \x03(\x0b\x32%.injective.exchange.v2.AccountRewardsR\x0e\x61\x63\x63ountRewards\"\xb0\x01\n\"EventNewConditionalDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12<\n\x05order\x18\x02 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderR\x05order\x12\x12\n\x04hash\x18\x03 \x01(\x0cR\x04hash\x12\x1b\n\tis_market\x18\x04 \x01(\x08R\x08isMarket\"\x95\x02\n%EventCancelConditionalDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12$\n\risLimitCancel\x18\x02 \x01(\x08R\risLimitCancel\x12R\n\x0blimit_order\x18\x03 \x01(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01R\nlimitOrder\x12U\n\x0cmarket_order\x18\x04 \x01(\x0b\x32,.injective.exchange.v2.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01R\x0bmarketOrder\"\xfb\x01\n&EventConditionalDerivativeOrderTrigger\x12\x1b\n\tmarket_id\x18\x01 \x01(\x0cR\x08marketId\x12&\n\x0eisLimitTrigger\x18\x02 \x01(\x08R\x0eisLimitTrigger\x12\x30\n\x14triggered_order_hash\x18\x03 \x01(\x0cR\x12triggeredOrderHash\x12*\n\x11placed_order_hash\x18\x04 \x01(\x0cR\x0fplacedOrderHash\x12.\n\x13triggered_order_cid\x18\x05 \x01(\tR\x11triggeredOrderCid\"l\n\x0e\x45ventOrderFail\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0cR\x07\x61\x63\x63ount\x12\x16\n\x06hashes\x18\x02 \x03(\x0cR\x06hashes\x12\x14\n\x05\x66lags\x18\x03 \x03(\rR\x05\x66lags\x12\x12\n\x04\x63ids\x18\x04 \x03(\tR\x04\x63ids\"\x8f\x01\n+EventAtomicMarketOrderFeeMultipliersUpdated\x12`\n\x16market_fee_multipliers\x18\x01 \x03(\x0b\x32*.injective.exchange.v2.MarketFeeMultiplierR\x14marketFeeMultipliers\"\xb8\x01\n\x14\x45ventOrderbookUpdate\x12I\n\x0cspot_updates\x18\x01 \x03(\x0b\x32&.injective.exchange.v2.OrderbookUpdateR\x0bspotUpdates\x12U\n\x12\x64\x65rivative_updates\x18\x02 \x03(\x0b\x32&.injective.exchange.v2.OrderbookUpdateR\x11\x64\x65rivativeUpdates\"c\n\x0fOrderbookUpdate\x12\x10\n\x03seq\x18\x01 \x01(\x04R\x03seq\x12>\n\torderbook\x18\x02 \x01(\x0b\x32 .injective.exchange.v2.OrderbookR\torderbook\"\xa4\x01\n\tOrderbook\x12\x1b\n\tmarket_id\x18\x01 \x01(\x0cR\x08marketId\x12;\n\nbuy_levels\x18\x02 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\tbuyLevels\x12=\n\x0bsell_levels\x18\x03 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\nsellLevels\"w\n\x18\x45ventGrantAuthorizations\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12\x41\n\x06grants\x18\x02 \x03(\x0b\x32).injective.exchange.v2.GrantAuthorizationR\x06grants\"\x81\x01\n\x14\x45ventGrantActivation\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\x12\x18\n\x07granter\x18\x02 \x01(\tR\x07granter\x12\x35\n\x06\x61mount\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\"G\n\x11\x45ventInvalidGrant\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\x12\x18\n\x07granter\x18\x02 \x01(\tR\x07granter\"\xab\x01\n\x14\x45ventOrderCancelFail\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x03 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x04 \x01(\tR\x03\x63id\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\"\xfb\x01\n EventDerivativeOrdersV2Migration\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12[\n\x11\x62uy_order_changes\x18\x02 \x03(\x0b\x32/.injective.exchange.v2.DerivativeOrderV2ChangesR\x0f\x62uyOrderChanges\x12]\n\x12sell_order_changes\x18\x03 \x03(\x0b\x32/.injective.exchange.v2.DerivativeOrderV2ChangesR\x10sellOrderChanges\"\xc1\x02\n\x18\x44\x65rivativeOrderV2Changes\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\x12\x31\n\x01p\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01p\x12\x31\n\x01q\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01q\x12\x31\n\x01m\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01m\x12\x31\n\x01\x66\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01\x66\x12\x33\n\x02tp\x18\x07 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x02tp\"\xe9\x01\n\x1a\x45ventSpotOrdersV2Migration\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12U\n\x11\x62uy_order_changes\x18\x02 \x03(\x0b\x32).injective.exchange.v2.SpotOrderV2ChangesR\x0f\x62uyOrderChanges\x12W\n\x12sell_order_changes\x18\x03 \x03(\x0b\x32).injective.exchange.v2.SpotOrderV2ChangesR\x10sellOrderChanges\"\xf0\x01\n(EventTriggerConditionalMarketOrderFailed\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x42\n\nmark_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\x12\x1d\n\norder_hash\x18\x04 \x01(\x0cR\torderHash\x12\x1f\n\x0btrigger_err\x18\x05 \x01(\tR\ntriggerErr\"\xef\x01\n\'EventTriggerConditionalLimitOrderFailed\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x42\n\nmark_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\x12\x1d\n\norder_hash\x18\x04 \x01(\x0cR\torderHash\x12\x1f\n\x0btrigger_err\x18\x05 \x01(\tR\ntriggerErr\"\x88\x02\n\x12SpotOrderV2Changes\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\x12\x31\n\x01p\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01p\x12\x31\n\x01q\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01q\x12\x31\n\x01\x66\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x01\x66\x12\x33\n\x02tp\x18\x06 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x02tp\"k\n\"EventDerivativePositionV2Migration\x12\x45\n\x08position\x18\x01 \x01(\x0b\x32).injective.exchange.v2.DerivativePositionR\x08positionB\xf1\x01\n\x19\x63om.injective.exchange.v2B\x0b\x45ventsProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\013EventsProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_EVENTBATCHDERIVATIVEEXECUTION'].fields_by_name['cumulative_funding']._loaded_options = None
  _globals['_EVENTBATCHDERIVATIVEEXECUTION'].fields_by_name['cumulative_funding']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_available_during_payout']._loaded_options = None
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_available_during_payout']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_order_cancels']._loaded_options = None
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_order_cancels']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTCANCELSPOTORDER'].fields_by_name['order']._loaded_options = None
  _globals['_EVENTCANCELSPOTORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSPOTMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTSPOTMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['perpetual_market_info']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['perpetual_market_info']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['funding']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['funding']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['expiry_futures_market_info']._loaded_options = None
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['expiry_futures_market_info']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding_rate']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding_rate']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['mark_price']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTSUBACCOUNTDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTDEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSUBACCOUNTWITHDRAW'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTWITHDRAW'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['market_order']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['market_order']._serialized_options = b'\310\336\037\001'
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['cancel_quantity']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['cancel_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['limit_order']._loaded_options = None
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['limit_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['market_order_cancel']._loaded_options = None
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['market_order_cancel']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['limit_order']._loaded_options = None
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['limit_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['market_order']._loaded_options = None
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['market_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTGRANTACTIVATION'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTGRANTACTIVATION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['p']._loaded_options = None
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['p']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['q']._loaded_options = None
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['q']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['m']._loaded_options = None
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['m']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['f']._loaded_options = None
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['f']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['tp']._loaded_options = None
  _globals['_DERIVATIVEORDERV2CHANGES'].fields_by_name['tp']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTTRIGGERCONDITIONALMARKETORDERFAILED'].fields_by_name['mark_price']._loaded_options = None
  _globals['_EVENTTRIGGERCONDITIONALMARKETORDERFAILED'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTTRIGGERCONDITIONALLIMITORDERFAILED'].fields_by_name['mark_price']._loaded_options = None
  _globals['_EVENTTRIGGERCONDITIONALLIMITORDERFAILED'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['p']._loaded_options = None
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['p']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['q']._loaded_options = None
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['q']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['f']._loaded_options = None
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['f']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['tp']._loaded_options = None
  _globals['_SPOTORDERV2CHANGES'].fields_by_name['tp']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTBATCHSPOTEXECUTION']._serialized_start=264
  _globals['_EVENTBATCHSPOTEXECUTION']._serialized_end=474
  _globals['_EVENTBATCHDERIVATIVEEXECUTION']._serialized_start=477
  _globals['_EVENTBATCHDERIVATIVEEXECUTION']._serialized_end=826
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION']._serialized_start=829
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION']._serialized_end=1151
  _globals['_EVENTBATCHDERIVATIVEPOSITION']._serialized_start=1154
  _globals['_EVENTBATCHDERIVATIVEPOSITION']._serialized_end=1286
  _globals['_EVENTDERIVATIVEMARKETPAUSED']._serialized_start=1289
  _globals['_EVENTDERIVATIVEMARKETPAUSED']._serialized_end=1476
  _globals['_EVENTSETTLEDMARKETBALANCE']._serialized_start=1478
  _globals['_EVENTSETTLEDMARKETBALANCE']._serialized_end=1558
  _globals['_EVENTNOTSETTLEDMARKETBALANCE']._serialized_start=1560
  _globals['_EVENTNOTSETTLEDMARKETBALANCE']._serialized_end=1643
  _globals['_EVENTMARKETBEYONDBANKRUPTCY']._serialized_start=1646
  _globals['_EVENTMARKETBEYONDBANKRUPTCY']._serialized_end=1789
  _globals['_EVENTALLPOSITIONSHAIRCUT']._serialized_start=1792
  _globals['_EVENTALLPOSITIONSHAIRCUT']._serialized_end=1928
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE']._serialized_start=1930
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE']._serialized_end=2036
  _globals['_EVENTNEWSPOTORDERS']._serialized_start=2039
  _globals['_EVENTNEWSPOTORDERS']._serialized_end=2230
  _globals['_EVENTNEWDERIVATIVEORDERS']._serialized_start=2233
  _globals['_EVENTNEWDERIVATIVEORDERS']._serialized_end=2442
  _globals['_EVENTCANCELSPOTORDER']._serialized_start=2444
  _globals['_EVENTCANCELSPOTORDER']._serialized_end=2562
  _globals['_EVENTSPOTMARKETUPDATE']._serialized_start=2564
  _globals['_EVENTSPOTMARKETUPDATE']._serialized_end=2652
  _globals['_EVENTPERPETUALMARKETUPDATE']._serialized_start=2655
  _globals['_EVENTPERPETUALMARKETUPDATE']._serialized_end=2935
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE']._serialized_start=2938
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE']._serialized_end=3156
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE']._serialized_start=3159
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE']._serialized_end=3486
  _globals['_EVENTSUBACCOUNTDEPOSIT']._serialized_start=3489
  _globals['_EVENTSUBACCOUNTDEPOSIT']._serialized_end=3640
  _globals['_EVENTSUBACCOUNTWITHDRAW']._serialized_start=3643
  _globals['_EVENTSUBACCOUNTWITHDRAW']._serialized_end=3795
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER']._serialized_start=3798
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER']._serialized_end=3975
  _globals['_EVENTBATCHDEPOSITUPDATE']._serialized_start=3977
  _globals['_EVENTBATCHDEPOSITUPDATE']._serialized_end=4081
  _globals['_DERIVATIVEMARKETORDERCANCEL']._serialized_start=4084
  _globals['_DERIVATIVEMARKETORDERCANCEL']._serialized_end=4278
  _globals['_EVENTCANCELDERIVATIVEORDER']._serialized_start=4281
  _globals['_EVENTCANCELDERIVATIVEORDER']._serialized_end=4566
  _globals['_EVENTFEEDISCOUNTSCHEDULE']._serialized_start=4568
  _globals['_EVENTFEEDISCOUNTSCHEDULE']._serialized_end=4666
  _globals['_EVENTTRADINGREWARDCAMPAIGNUPDATE']._serialized_start=4669
  _globals['_EVENTTRADINGREWARDCAMPAIGNUPDATE']._serialized_end=4885
  _globals['_EVENTTRADINGREWARDDISTRIBUTION']._serialized_start=4887
  _globals['_EVENTTRADINGREWARDDISTRIBUTION']._serialized_end=4999
  _globals['_EVENTNEWCONDITIONALDERIVATIVEORDER']._serialized_start=5002
  _globals['_EVENTNEWCONDITIONALDERIVATIVEORDER']._serialized_end=5178
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER']._serialized_start=5181
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER']._serialized_end=5458
  _globals['_EVENTCONDITIONALDERIVATIVEORDERTRIGGER']._serialized_start=5461
  _globals['_EVENTCONDITIONALDERIVATIVEORDERTRIGGER']._serialized_end=5712
  _globals['_EVENTORDERFAIL']._serialized_start=5714
  _globals['_EVENTORDERFAIL']._serialized_end=5822
  _globals['_EVENTATOMICMARKETORDERFEEMULTIPLIERSUPDATED']._serialized_start=5825
  _globals['_EVENTATOMICMARKETORDERFEEMULTIPLIERSUPDATED']._serialized_end=5968
  _globals['_EVENTORDERBOOKUPDATE']._serialized_start=5971
  _globals['_EVENTORDERBOOKUPDATE']._serialized_end=6155
  _globals['_ORDERBOOKUPDATE']._serialized_start=6157
  _globals['_ORDERBOOKUPDATE']._serialized_end=6256
  _globals['_ORDERBOOK']._serialized_start=6259
  _globals['_ORDERBOOK']._serialized_end=6423
  _globals['_EVENTGRANTAUTHORIZATIONS']._serialized_start=6425
  _globals['_EVENTGRANTAUTHORIZATIONS']._serialized_end=6544
  _globals['_EVENTGRANTACTIVATION']._serialized_start=6547
  _globals['_EVENTGRANTACTIVATION']._serialized_end=6676
  _globals['_EVENTINVALIDGRANT']._serialized_start=6678
  _globals['_EVENTINVALIDGRANT']._serialized_end=6749
  _globals['_EVENTORDERCANCELFAIL']._serialized_start=6752
  _globals['_EVENTORDERCANCELFAIL']._serialized_end=6923
  _globals['_EVENTDERIVATIVEORDERSV2MIGRATION']._serialized_start=6926
  _globals['_EVENTDERIVATIVEORDERSV2MIGRATION']._serialized_end=7177
  _globals['_DERIVATIVEORDERV2CHANGES']._serialized_start=7180
  _globals['_DERIVATIVEORDERV2CHANGES']._serialized_end=7501
  _globals['_EVENTSPOTORDERSV2MIGRATION']._serialized_start=7504
  _globals['_EVENTSPOTORDERSV2MIGRATION']._serialized_end=7737
  _globals['_EVENTTRIGGERCONDITIONALMARKETORDERFAILED']._serialized_start=7740
  _globals['_EVENTTRIGGERCONDITIONALMARKETORDERFAILED']._serialized_end=7980
  _globals['_EVENTTRIGGERCONDITIONALLIMITORDERFAILED']._serialized_start=7983
  _globals['_EVENTTRIGGERCONDITIONALLIMITORDERFAILED']._serialized_end=8222
  _globals['_SPOTORDERV2CHANGES']._serialized_start=8225
  _globals['_SPOTORDERV2CHANGES']._serialized_end=8489
  _globals['_EVENTDERIVATIVEPOSITIONV2MIGRATION']._serialized_start=8491
  _globals['_EVENTDERIVATIVEPOSITIONV2MIGRATION']._serialized_end=8598
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/mempool/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/mempool/v1/types.proto\x12\x13\x63ometbft.mempool.v1\"\x17\n\x03Txs\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\">\n\x07Message\x12,\n\x03txs\x18\x01 \x01(\x0b\x32\x18.cometbft.mempool.v1.TxsH\x00R\x03txsB\x05\n\x03sumB\xc9\x01\n\x17\x63om.cometbft.mempool.v1B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1\xa2\x02\x03\x43MX\xaa\x02\x13\x43ometbft.Mempool.V1\xca\x02\x13\x43ometbft\\Mempool\\V1\xe2\x02\x1f\x43ometbft\\Mempool\\V1\\GPBMetadata\xea\x02\x15\x43ometbft::Mempool::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.mempool.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.mempool.v1B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1\242\002\003CMX\252\002\023Cometbft.Mempool.V1\312\002\023Cometbft\\Mempool\\V1\342\002\037Cometbft\\Mempool\\V1\\GPBMetadata\352\002\025Cometbft::Mempool::V1'
  _globals['_TXS']._serialized_start=56
  _globals['_TXS']._serialized_end=79
  _globals['_MESSAGE']._serialized_start=81
  _globals['_MESSAGE']._serialized_end=143
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/circuit/v1/types.proto\x12\x11\x63osmos.circuit.v1\"\xd6\x01\n\x0bPermissions\x12:\n\x05level\x18\x01 \x01(\x0e\x32$.cosmos.circuit.v1.Permissions.LevelR\x05level\x12&\n\x0flimit_type_urls\x18\x02 \x03(\tR\rlimitTypeUrls\"c\n\x05Level\x12\x1a\n\x16LEVEL_NONE_UNSPECIFIED\x10\x00\x12\x13\n\x0fLEVEL_SOME_MSGS\x10\x01\x12\x12\n\x0eLEVEL_ALL_MSGS\x10\x02\x12\x15\n\x11LEVEL_SUPER_ADMIN\x10\x03\"w\n\x19GenesisAccountPermissions\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12@\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x1e.cosmos.circuit.v1.PermissionsR\x0bpermissions\"\x9b\x01\n\x0cGenesisState\x12]\n\x13\x61\x63\x63ount_permissions\x18\x01 \x03(\x0b\x32,.cosmos.circuit.v1.GenesisAccountPermissionsR\x12\x61\x63\x63ountPermissions\x12,\n\x12\x64isabled_type_urls\x18\x02 \x03(\tR\x10\x64isabledTypeUrlsB\xa7\x01\n\x15\x63om.cosmos.circuit.v1B\nTypesProtoP\x01Z\x1c\x63osmossdk.io/x/circuit/types\xa2\x02\x03\x43\x43X\xaa\x02\x11\x43osmos.Circuit.V1\xca\x02\x11\x43osmos\\Circuit\\V1\xe2\x02\x1d\x43osmos\\Circuit\\V1\\GPBMetadata\xea\x02\x13\x43osmos::Circuit::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cosmos.circuit.v1B\nTypesProtoP\001Z\034cosmossdk.io/x/circuit/types\242\002\003CCX\252\002\021Cosmos.Circuit.V1\312\002\021Cosmos\\Circuit\\V1\342\002\035Cosmos\\Circuit\\V1\\GPBMetadata\352\002\023Cosmos::Circuit::V1'
  _globals['_PERMISSIONS']._serialized_start=53
  _globals['_PERMISSIONS']._serialized_end=267
  _globals['_PERMISSIONS_LEVEL']._serialized_start=168
  _globals['_PERMISSIONS_LEVEL']._serialized_end=267
  _globals['_GENESISACCOUNTPERMISSIONS']._serialized_start=269
  _globals['_GENESISACCOUNTPERMISSIONS']._serialized_end=388
  _globals['_GENESISSTATE']._serialized_start=391
  _globals['_GENESISSTATE']._serialized_end=546
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/evidence/v1beta1/genesis.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x19google/protobuf/any.proto\"@\n\x0cGenesisState\x12\x30\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x08\x65videnceB\xc8\x01\n\x1b\x63om.cosmos.evidence.v1beta1B\x0cGenesisProtoP\x01Z\x1d\x63osmossdk.io/x/evidence/types\xa2\x02\x03\x43\x45X\xaa\x02\x17\x43osmos.Evidence.V1beta1\xca\x02\x17\x43osmos\\Evidence\\V1beta1\xe2\x02#Cosmos\\Evidence\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Evidence::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.evidence.v1beta1B\014GenesisProtoP\001Z\035cosmossdk.io/x/evidence/types\242\002\003CEX\252\002\027Cosmos.Evidence.V1beta1\312\002\027Cosmos\\Evidence\\V1beta1\342\002#Cosmos\\Evidence\\V1beta1\\GPBMetadata\352\002\031Cosmos::Evidence::V1beta1'
  _globals['_GENESISSTATE']._serialized_start=93
  _globals['_GENESISSTATE']._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/secp256r1/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/crypto/secp256r1/keys.proto\x12\x17\x63osmos.crypto.secp256r1\x1a\x14gogoproto/gogo.proto\"\'\n\x06PubKey\x12\x1d\n\x03key\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saPKR\x03key\".\n\x07PrivKey\x12#\n\x06secret\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saSKR\x06secretB\xe6\x01\n\x1b\x63om.cosmos.crypto.secp256r1B\tKeysProtoP\x01Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xa2\x02\x03\x43\x43S\xaa\x02\x17\x43osmos.Crypto.Secp256r1\xca\x02\x17\x43osmos\\Crypto\\Secp256r1\xe2\x02#Cosmos\\Crypto\\Secp256r1\\GPBMetadata\xea\x02\x19\x43osmos::Crypto::Secp256r1\xc8\xe1\x1e\x00\xd8\xe1\x1e\x00\xc8\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256r1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.crypto.secp256r1B\tKeysProtoP\001Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\242\002\003CCS\252\002\027Cosmos.Crypto.Secp256r1\312\002\027Cosmos\\Crypto\\Secp256r1\342\002#Cosmos\\Crypto\\Secp256r1\\GPBMetadata\352\002\031Cosmos::Crypto::Secp256r1\310\341\036\000\330\341\036\000\310\343\036\001'
  _globals['_PUBKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PUBKEY'].fields_by_name['key']._serialized_options = b'\332\336\037\007ecdsaPK'
  _globals['_PRIVKEY'].fields_by_name['secret']._loaded_options = None
  _globals['_PRIVKEY'].fields_by_name['secret']._serialized_options = b'\332\336\037\007ecdsaSK'
  _globals['_PUBKEY']._serialized_start=85
  _globals['_PUBKEY']._serialized_end=124
  _globals['_PRIVKEY']._serialized_start=126
  _globals['_PRIVKEY']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/chain_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/evm/v1/chain_config.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\"\xa7\x11\n\x0b\x43hainConfig\x12\\\n\x0fhomestead_block\x18\x01 \x01(\tB3\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x16yaml:\"homestead_block\"R\x0ehomesteadBlock\x12h\n\x0e\x64\x61o_fork_block\x18\x02 \x01(\tBB\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x0c\x44\x41OForkBlock\xf2\xde\x1f\x15yaml:\"dao_fork_block\"R\x0c\x64\x61oForkBlock\x12W\n\x10\x64\x61o_fork_support\x18\x03 \x01(\x08\x42-\xe2\xde\x1f\x0e\x44\x41OForkSupport\xf2\xde\x1f\x17yaml:\"dao_fork_support\"R\x0e\x64\x61oForkSupport\x12\x62\n\x0c\x65ip150_block\x18\x04 \x01(\tB?\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x0b\x45IP150Block\xf2\xde\x1f\x13yaml:\"eip150_block\"R\x0b\x65ip150Block\x12I\n\x0b\x65ip150_hash\x18\x05 \x01(\tB(\xe2\xde\x1f\nEIP150Hash\xf2\xde\x1f\x16yaml:\"byzantium_block\"R\neip150Hash\x12\x62\n\x0c\x65ip155_block\x18\x06 \x01(\tB?\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x0b\x45IP155Block\xf2\xde\x1f\x13yaml:\"eip155_block\"R\x0b\x65ip155Block\x12\x62\n\x0c\x65ip158_block\x18\x07 \x01(\tB?\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x0b\x45IP158Block\xf2\xde\x1f\x13yaml:\"eip158_block\"R\x0b\x65ip158Block\x12\\\n\x0f\x62yzantium_block\x18\x08 \x01(\tB3\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x16yaml:\"byzantium_block\"R\x0e\x62yzantiumBlock\x12k\n\x14\x63onstantinople_block\x18\t \x01(\tB8\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x1byaml:\"constantinople_block\"R\x13\x63onstantinopleBlock\x12_\n\x10petersburg_block\x18\n \x01(\tB4\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x17yaml:\"petersburg_block\"R\x0fpetersburgBlock\x12Y\n\x0eistanbul_block\x18\x0b \x01(\tB2\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x15yaml:\"istanbul_block\"R\ristanbulBlock\x12\x64\n\x12muir_glacier_block\x18\x0c \x01(\tB6\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x19yaml:\"muir_glacier_block\"R\x10muirGlacierBlock\x12S\n\x0c\x62\x65rlin_block\x18\r \x01(\tB0\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x13yaml:\"berlin_block\"R\x0b\x62\x65rlinBlock\x12S\n\x0clondon_block\x18\x11 \x01(\tB0\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x13yaml:\"london_block\"R\x0blondonBlock\x12g\n\x13\x61rrow_glacier_block\x18\x12 \x01(\tB7\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x1ayaml:\"arrow_glacier_block\"R\x11\x61rrowGlacierBlock\x12\x64\n\x12gray_glacier_block\x18\x14 \x01(\tB6\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x19yaml:\"gray_glacier_block\"R\x10grayGlacierBlock\x12j\n\x14merge_netsplit_block\x18\x15 \x01(\tB8\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x1byaml:\"merge_netsplit_block\"R\x12mergeNetsplitBlock\x12V\n\rshanghai_time\x18\x16 \x01(\tB1\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x14yaml:\"shanghai_time\"R\x0cshanghaiTime\x12P\n\x0b\x63\x61ncun_time\x18\x17 \x01(\tB/\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x12yaml:\"cancun_time\"R\ncancunTime\x12P\n\x0bprague_time\x18\x18 \x01(\tB/\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xf2\xde\x1f\x12yaml:\"prague_time\"R\npragueTime\x12\x63\n\x0f\x65ip155_chain_id\x18\x19 \x01(\tB;\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\rEIP155ChainID\xea\xde\x1f\reip155ChainIDR\reip155ChainId\x12w\n\x14\x62lob_schedule_config\x18\x1a \x01(\x0b\x32$.injective.evm.v1.BlobScheduleConfigB\x1f\xf2\xde\x1f\x1byaml:\"blob_schedule_config\"R\x12\x62lobScheduleConfigJ\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x13\x10\x14R\ryolo_v3_blockR\x0b\x65wasm_blockR\x0e\x63\x61talyst_blockR\x10merge_fork_block\"\xea\x01\n\x12\x42lobScheduleConfig\x12\x34\n\x06\x63\x61ncun\x18\x01 \x01(\x0b\x32\x1c.injective.evm.v1.BlobConfigR\x06\x63\x61ncun\x12\x34\n\x06prague\x18\x02 \x01(\x0b\x32\x1c.injective.evm.v1.BlobConfigR\x06prague\x12\x32\n\x05osaka\x18\x03 \x01(\x0b\x32\x1c.injective.evm.v1.BlobConfigR\x05osaka\x12\x34\n\x06verkle\x18\x04 \x01(\x0b\x32\x1c.injective.evm.v1.BlobConfigR\x06verkle\"\x94\x01\n\nBlobConfig\x12\x16\n\x06target\x18\x01 \x01(\x04R\x06target\x12\x10\n\x03max\x18\x02 \x01(\x04R\x03max\x12\\\n\x18\x62\x61se_fee_update_fraction\x18\x03 \x01(\x04\x42#\xf2\xde\x1f\x1fyaml:\"base_fee_update_fraction\"R\x15\x62\x61seFeeUpdateFractionB\xd5\x01\n\x14\x63om.injective.evm.v1B\x10\x43hainConfigProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.chain_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\020ChainConfigProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_CHAINCONFIG'].fields_by_name['homestead_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['homestead_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\026yaml:\"homestead_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['dao_fork_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['dao_fork_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\014DAOForkBlock\362\336\037\025yaml:\"dao_fork_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['dao_fork_support']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['dao_fork_support']._serialized_options = b'\342\336\037\016DAOForkSupport\362\336\037\027yaml:\"dao_fork_support\"'
  _globals['_CHAINCONFIG'].fields_by_name['eip150_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['eip150_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\013EIP150Block\362\336\037\023yaml:\"eip150_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['eip150_hash']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['eip150_hash']._serialized_options = b'\342\336\037\nEIP150Hash\362\336\037\026yaml:\"byzantium_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['eip155_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['eip155_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\013EIP155Block\362\336\037\023yaml:\"eip155_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['eip158_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['eip158_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\013EIP158Block\362\336\037\023yaml:\"eip158_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['byzantium_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['byzantium_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\026yaml:\"byzantium_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['constantinople_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['constantinople_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\033yaml:\"constantinople_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['petersburg_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['petersburg_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\027yaml:\"petersburg_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['istanbul_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['istanbul_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\025yaml:\"istanbul_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['muir_glacier_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['muir_glacier_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\031yaml:\"muir_glacier_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['berlin_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['berlin_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\023yaml:\"berlin_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['london_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['london_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\023yaml:\"london_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['arrow_glacier_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['arrow_glacier_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\032yaml:\"arrow_glacier_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['gray_glacier_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['gray_glacier_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\031yaml:\"gray_glacier_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['merge_netsplit_block']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['merge_netsplit_block']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\033yaml:\"merge_netsplit_block\"'
  _globals['_CHAINCONFIG'].fields_by_name['shanghai_time']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['shanghai_time']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\024yaml:\"shanghai_time\"'
  _globals['_CHAINCONFIG'].fields_by_name['cancun_time']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['cancun_time']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\022yaml:\"cancun_time\"'
  _globals['_CHAINCONFIG'].fields_by_name['prague_time']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['prague_time']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\362\336\037\022yaml:\"prague_time\"'
  _globals['_CHAINCONFIG'].fields_by_name['eip155_chain_id']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['eip155_chain_id']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\rEIP155ChainID\352\336\037\reip155ChainID'
  _globals['_CHAINCONFIG'].fields_by_name['blob_schedule_config']._loaded_options = None
  _globals['_CHAINCONFIG'].fields_by_name['blob_schedule_config']._serialized_options = b'\362\336\037\033yaml:\"blob_schedule_config\"'
  _globals['_BLOBCONFIG'].fields_by_name['base_fee_update_fraction']._loaded_options = None
  _globals['_BLOBCONFIG'].fields_by_name['base_fee_update_fraction']._serialized_options = b'\362\336\037\037yaml:\"base_fee_update_fraction\"'
  _globals['_CHAINCONFIG']._serialized_start=80
  _globals['_CHAINCONFIG']._serialized_end=2295
  _globals['_BLOBSCHEDULECONFIG']._serialized_start=2298
  _globals['_BLOBSCHEDULECONFIG']._serialized_end=2532
  _globals['_BLOBCONFIG']._serialized_start=2535
  _globals['_BLOBCONFIG']._serialized_end=2683
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/keyring/v1/record.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos.crypto.hd.v1 import hd_pb2 as cosmos_dot_crypto_dot_hd_dot_v1_dot_hd__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/crypto/keyring/v1/record.proto\x12\x18\x63osmos.crypto.keyring.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1c\x63osmos/crypto/hd/v1/hd.proto\"\xea\x03\n\x06Record\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12-\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x06pubKey\x12>\n\x05local\x18\x03 \x01(\x0b\x32&.cosmos.crypto.keyring.v1.Record.LocalH\x00R\x05local\x12\x41\n\x06ledger\x18\x04 \x01(\x0b\x32\'.cosmos.crypto.keyring.v1.Record.LedgerH\x00R\x06ledger\x12>\n\x05multi\x18\x05 \x01(\x0b\x32&.cosmos.crypto.keyring.v1.Record.MultiH\x00R\x05multi\x12\x44\n\x07offline\x18\x06 \x01(\x0b\x32(.cosmos.crypto.keyring.v1.Record.OfflineH\x00R\x07offline\x1a\x38\n\x05Local\x12/\n\x08priv_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x07privKey\x1a>\n\x06Ledger\x12\x34\n\x04path\x18\x01 \x01(\x0b\x32 .cosmos.crypto.hd.v1.BIP44ParamsR\x04path\x1a\x07\n\x05Multi\x1a\t\n\x07OfflineB\x06\n\x04itemB\xe3\x01\n\x1c\x63om.cosmos.crypto.keyring.v1B\x0bRecordProtoP\x01Z+github.com/cosmos/cosmos-sdk/crypto/keyring\xa2\x02\x03\x43\x43K\xaa\x02\x18\x43osmos.Crypto.Keyring.V1\xca\x02\x18\x43osmos\\Crypto\\Keyring\\V1\xe2\x02$Cosmos\\Crypto\\Keyring\\V1\\GPBMetadata\xea\x02\x1b\x43osmos::Crypto::Keyring::V1\xc8\xe1\x1e\x00\x98\xe3\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.keyring.v1.record_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cosmos.crypto.keyring.v1B\013RecordProtoP\001Z+github.com/cosmos/cosmos-sdk/crypto/keyring\242\002\003CCK\252\002\030Cosmos.Crypto.Keyring.V1\312\002\030Cosmos\\Crypto\\Keyring\\V1\342\002$Cosmos\\Crypto\\Keyring\\V1\\GPBMetadata\352\002\033Cosmos::Crypto::Keyring::V1\310\341\036\000\230\343\036\000'
  _globals['_RECORD']._serialized_start=147
  _globals['_RECORD']._serialized_end=637
  _globals['_RECORD_LOCAL']._serialized_start=489
  _globals['_RECORD_LOCAL']._serialized_end=545
  _globals['_RECORD_LEDGER']._serialized_start=547
  _globals['_RECORD_LEDGER']._serialized_end=609
  _globals['_RECORD_MULTI']._serialized_start=611
  _globals['_RECORD_MULTI']._serialized_end=618
  _globals['_RECORD_OFFLINE']._serialized_start=620
  _globals['_RECORD_OFFLINE']._serialized_end=629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/connection/v1/tx.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\"\x8b\x02\n\x15MsgConnectionOpenInit\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12N\n\x0c\x63ounterparty\x18\x02 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12\x39\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x07version\x12!\n\x0c\x64\x65lay_period\x18\x04 \x01(\x04R\x0b\x64\x65layPeriod\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgConnectionOpenInitResponse\"\xe4\x05\n\x14MsgConnectionOpenTry\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x38\n\x16previous_connection_id\x18\x02 \x01(\tB\x02\x18\x01R\x14previousConnectionId\x12;\n\x0c\x63lient_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01R\x0b\x63lientState\x12N\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12!\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04R\x0b\x64\x65layPeriod\x12T\n\x15\x63ounterparty_versions\x18\x06 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x14\x63ounterpartyVersions\x12\x43\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x1d\n\nproof_init\x18\x08 \x01(\x0cR\tproofInit\x12%\n\x0cproof_client\x18\t \x01(\x0c\x42\x02\x18\x01R\x0bproofClient\x12+\n\x0fproof_consensus\x18\n \x01(\x0c\x42\x02\x18\x01R\x0eproofConsensus\x12M\n\x10\x63onsensus_height\x18\x0b \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x06\x18\x01\xc8\xde\x1f\x00R\x0f\x63onsensusHeight\x12\x16\n\x06signer\x18\x0c \x01(\tR\x06signer\x12?\n\x1ahost_consensus_state_proof\x18\r \x01(\x0c\x42\x02\x18\x01R\x17hostConsensusStateProof:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1e\n\x1cMsgConnectionOpenTryResponse\"\xe0\x04\n\x14MsgConnectionOpenAck\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12<\n\x1a\x63ounterparty_connection_id\x18\x02 \x01(\tR\x18\x63ounterpartyConnectionId\x12\x39\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x07version\x12;\n\x0c\x63lient_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01R\x0b\x63lientState\x12\x43\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x1b\n\tproof_try\x18\x06 \x01(\x0cR\x08proofTry\x12%\n\x0cproof_client\x18\x07 \x01(\x0c\x42\x02\x18\x01R\x0bproofClient\x12+\n\x0fproof_consensus\x18\x08 \x01(\x0c\x42\x02\x18\x01R\x0eproofConsensus\x12M\n\x10\x63onsensus_height\x18\t \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x06\x18\x01\xc8\xde\x1f\x00R\x0f\x63onsensusHeight\x12\x16\n\x06signer\x18\n \x01(\tR\x06signer\x12?\n\x1ahost_consensus_state_proof\x18\x0b \x01(\x0c\x42\x02\x18\x01R\x17hostConsensusStateProof:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1e\n\x1cMsgConnectionOpenAckResponse\"\xca\x01\n\x18MsgConnectionOpenConfirm\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12\x1b\n\tproof_ack\x18\x02 \x01(\x0cR\x08proofAck\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\"\n MsgConnectionOpenConfirmResponse\"x\n\x0fMsgUpdateParams\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12<\n\x06params\x18\x02 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateParamsResponse2\xf4\x04\n\x03Msg\x12z\n\x12\x43onnectionOpenInit\x12-.ibc.core.connection.v1.MsgConnectionOpenInit\x1a\x35.ibc.core.connection.v1.MsgConnectionOpenInitResponse\x12w\n\x11\x43onnectionOpenTry\x12,.ibc.core.connection.v1.MsgConnectionOpenTry\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenTryResponse\x12w\n\x11\x43onnectionOpenAck\x12,.ibc.core.connection.v1.MsgConnectionOpenAck\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenAckResponse\x12\x83\x01\n\x15\x43onnectionOpenConfirm\x12\x30.ibc.core.connection.v1.MsgConnectionOpenConfirm\x1a\x38.ibc.core.connection.v1.MsgConnectionOpenConfirmResponse\x12r\n\x16UpdateConnectionParams\x12\'.ibc.core.connection.v1.MsgUpdateParams\x1a/.ibc.core.connection.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xde\x01\n\x1a\x63om.ibc.core.connection.v1B\x07TxProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\007TxProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_MSGCONNECTIONOPENINIT'].fields_by_name['counterparty']._loaded_options = None
  _globals['_MSGCONNECTIONOPENINIT'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCONNECTIONOPENINIT']._loaded_options = None
  _globals['_MSGCONNECTIONOPENINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['previous_connection_id']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['previous_connection_id']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['client_state']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['client_state']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['counterparty']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_client']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_client']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_consensus']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['proof_consensus']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['consensus_height']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['consensus_height']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['host_consensus_state_proof']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY'].fields_by_name['host_consensus_state_proof']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENTRY']._loaded_options = None
  _globals['_MSGCONNECTIONOPENTRY']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['client_state']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['client_state']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_client']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_client']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_consensus']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['proof_consensus']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['consensus_height']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['consensus_height']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['host_consensus_state_proof']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK'].fields_by_name['host_consensus_state_proof']._serialized_options = b'\030\001'
  _globals['_MSGCONNECTIONOPENACK']._loaded_options = None
  _globals['_MSGCONNECTIONOPENACK']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCONNECTIONOPENCONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCONNECTIONOPENCONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCONNECTIONOPENCONFIRM']._loaded_options = None
  _globals['_MSGCONNECTIONOPENCONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCONNECTIONOPENINIT']._serialized_start=208
  _globals['_MSGCONNECTIONOPENINIT']._serialized_end=475
  _globals['_MSGCONNECTIONOPENINITRESPONSE']._serialized_start=477
  _globals['_MSGCONNECTIONOPENINITRESPONSE']._serialized_end=508
  _globals['_MSGCONNECTIONOPENTRY']._serialized_start=511
  _globals['_MSGCONNECTIONOPENTRY']._serialized_end=1251
  _globals['_MSGCONNECTIONOPENTRYRESPONSE']._serialized_start=1253
  _globals['_MSGCONNECTIONOPENTRYRESPONSE']._serialized_end=1283
  _globals['_MSGCONNECTIONOPENACK']._serialized_start=1286
  _globals['_MSGCONNECTIONOPENACK']._serialized_end=1894
  _globals['_MSGCONNECTIONOPENACKRESPONSE']._serialized_start=1896
  _globals['_MSGCONNECTIONOPENACKRESPONSE']._serialized_end=1926
  _globals['_MSGCONNECTIONOPENCONFIRM']._serialized_start=1929
  _globals['_MSGCONNECTIONOPENCONFIRM']._serialized_end=2131
  _globals['_MSGCONNECTIONOPENCONFIRMRESPONSE']._serialized_start=2133
  _globals['_MSGCONNECTIONOPENCONFIRMRESPONSE']._serialized_end=2167
  _globals['_MSGUPDATEPARAMS']._serialized_start=2169
  _globals['_MSGUPDATEPARAMS']._serialized_end=2289
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=2291
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=2316
  _globals['_MSG']._serialized_start=2319
  _globals['_MSG']._serialized_end=2947
# @@protoc_insertion_point(module_scope)
